@@ -1,33 +1,53 @@
 /*
- * SPDX-FileCopyrightText: 2014 Daniel Vrátil <dvratil@redhat.com>
+ * Copyright (C) 2014  Daniel Vrátil <dvratil@redhat.com>
  *
- * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) version 3, or any
+ * later version accepted by the membership of KDE e.V. (or its
+ * successor approved by the membership of KDE e.V.), which shall
+ * act as a proxy defined in Section 6 of version 3 of the license.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "commentapprovejob.h"
-#include "account.h"
-#include "bloggerservice.h"
 #include "comment.h"
+#include "bloggerservice.h"
+#include "account.h"
 #include "utils.h"
 
-#include <QNetworkReply>
 #include <QNetworkRequest>
+#include <QNetworkReply>
 
 using namespace KGAPI2;
 using namespace KGAPI2::Blogger;
 
 class Q_DECL_HIDDEN CommentApproveJob::Private
 {
-public:
-    Private(const QString &blogId, const QString &postId, const QString &commentId, ApprovalAction action);
+  public:
+    Private(const QString &blogId,
+            const QString &postId,
+            const QString &commentId,
+            ApprovalAction action);
 
-    const QString blogId;
-    const QString postId;
-    const QString commentId;
-    const ApprovalAction action;
+    QString blogId;
+    QString postId;
+    QString commentId;
+    ApprovalAction action;
 };
 
-CommentApproveJob::Private::Private(const QString &blogId_, const QString &postId_, const QString &commentId_, CommentApproveJob::ApprovalAction action_)
+CommentApproveJob::Private::Private(const QString &blogId_,
+                                    const QString &postId_,
+                                    const QString &commentId_,
+                                    CommentApproveJob::ApprovalAction action_)
     : blogId(blogId_)
     , postId(postId_)
     , commentId(commentId_)
@@ -46,12 +66,16 @@ CommentApproveJob::CommentApproveJob(const QString &blogId,
 {
 }
 
-CommentApproveJob::CommentApproveJob(const CommentPtr &comment, CommentApproveJob::ApprovalAction action, const AccountPtr &account, QObject *parent)
+CommentApproveJob::CommentApproveJob(const CommentPtr &comment,
+                                     CommentApproveJob::ApprovalAction action,
+                                     const AccountPtr &account,
+                                     QObject *parent)
     : ModifyJob(account, parent)
     , d(new Private(comment->blogId(), comment->postId(), comment->id(), action))
 {
 }
 
+
 CommentApproveJob::~CommentApproveJob()
 {
     delete d;
@@ -85,3 +109,5 @@ ObjectsList CommentApproveJob::handleReplyWithItems(const QNetworkReply *reply,
     emitFinished();
     return items;
 }
+
+
