@@ -61,7 +61,9 @@ class KGAPITASKS_EXPORT Task: public KGAPI2::Object,
     /**
      * @brief Destructor
      */
-    virtual ~Task();
+    ~Task() override;
+
+    bool operator==(const Task &other) const;
 
     /**
      * @brief Sets whether the task has been deleted
